##
##  procmail.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2016 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         procmail
Summary:      Local Mail Filtering and Delivering Tool
URL:          http://www.procmail.org/
Vendor:       Stephen R. van den Berg
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        BASE
Group:        Mail
License:      GPL
Version:      3.22
Release:      20160305

#   package options
%option       with_fsl  yes

#   list of sources
Source0:      ftp://ftp.procmail.org/pub/procmail/procmail-%{version}.tar.gz
Source1:      procmailrc
Source2:      rc.procmail
Source3:      fsl.procmail
Patch0:       procmail.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20100101
PreReq:       OpenPKG, openpkg >= 20100101
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif

%description
    Procmail can be used to create mail-servers, mailing lists, sort
    your incoming mail into separate folders/files (real convenient
    when subscribing to one or more mailing lists or for prioritising
    your mail), preprocess your mail, start any programs upon mail
    arrival (e.g. to generate different chimes on your workstation for
    different types of mail) or selectively forward certain incoming
    mail automatically to someone.

%track
    prog procmail = {
        disabled
        comment   = "site gone"
        version   = %{version}
        url       = ftp://ftp.procmail.org/pub/procmail/
        regex     = procmail-(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0
    %{l_shtool} subst \
        -e 's;^\(BASENAME[^=]*=\).*;\1 %{l_prefix};' \
        -e 's;^CFLAGS0.*=.*$;CFLAGS0 = %{l_cflags -O};' \
        -e 's;^LDFLAGS0.*=\(.*\)$;LDFLAGS0 = %{l_ldflags} %{l_fsl_ldflags};' \
        -e 's;^LIBS.*=.*$;LIBS = %{l_fsl_libs};' \
        -e 's;^[#]*CC.*=.*$;CC = %{l_cc};' \
        Makefile
    %{l_shtool} subst \
        -e 's;^/\*\(#define NO_fcntl_LOCK\);\1;' \
        -e 's;^/\*\(#define LMTP\);\1;' \
        -e 's;\(#define.*ETCRC[^"]"\)[^"]*\(".*\);\1%{l_prefix}/etc/procmail/procmailrc\2;' \
        -e 's;\(#define.*ETCRCS[^"]"\)[^"]*\(".*\);\1%{l_prefix}/etc/procmail/\2;' \
        config.h
    %{l_shtool} subst \
        -e 's;getline;procmail_getline;g' \
        src/formisc.h src/formisc.c src/formail.c src/fields.c
%if "%{with_fsl}" == "yes"
    %{l_shtool} subst \
        -e 's;openlog(ident,logopt,facility);openlog(ident,logopt,LOG_USER);' \
        src/includes.h
%endif

%build
    ( unset LD_LIBRARY_PATH 2>/dev/null || true
      dirlist=""
      for dir in "$HOME/tmp" /tmp $RPM_SOURCE_DIR $RPM_BUILD_DIR; do
          if [ -d $dir ]; then
              dirlist="$dirlist $dir"
          fi
      done
      echo "$dirlist" |\
      %{l_make} %{l_mflags} autoconf.h CC="%{l_cc}" CFLAGS="%{l_cflags -O}"
    ) || exit $?
    %{l_shtool} subst \
        -e 's;\(#define.*SENDMAIL[^"]*"\)[^"]*\(".*\);\1%{l_prefix}/sbin/sendmail\2;' \
        autoconf.h
    %{l_make} %{l_mflags}

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/var/procmail \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/etc/procmail \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1 \
        $RPM_BUILD_ROOT%{l_prefix}/man/man5
    %{l_shtool} install -c -s -m 755 \
        new/procmail new/lockfile new/formail \
        $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 755 \
        new/mailstat \
        $RPM_BUILD_ROOT%{l_prefix}/bin/
    %{l_shtool} install -c -m 644 \
        new/*.1 $RPM_BUILD_ROOT%{l_prefix}/man/man1/
    %{l_shtool} install -c -m 644 \
        new/*.5 $RPM_BUILD_ROOT%{l_prefix}/man/man5/
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE procmailrc} $RPM_BUILD_ROOT%{l_prefix}/etc/procmail/

    #   install run-command script
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.procmail} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install OSSP fsl configuration
    %{l_shtool} mkdir -f -p -m 755 $RPM_BUILD_ROOT%{l_prefix}/etc/fsl
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fsl.procmail} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/fsl/fsl.procmail' \
        '%attr(6755,%{l_susr},mail) %{l_prefix}/bin/procmail' \
        '%attr(2755,%{l_mgrp},mail) %{l_prefix}/bin/lockfile'

%files -f files

%clean

